aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/message_parser.php
diff options
context:
space:
mode:
authorJoas Schilling <nickvergessen@gmx.de>2014-05-15 14:03:27 +0200
committerJoas Schilling <nickvergessen@gmx.de>2014-05-15 14:03:27 +0200
commit34c1691d7e5ccf607ee72366aa0b7b19474c71e4 (patch)
tree77a2e2bac3881f6a1fce970a4d952a8c02588711 /phpBB/includes/message_parser.php
parentbec9b7c34e63c7485477fa1edc2f6330889cc699 (diff)
downloadforums-34c1691d7e5ccf607ee72366aa0b7b19474c71e4.tar
forums-34c1691d7e5ccf607ee72366aa0b7b19474c71e4.tar.gz
forums-34c1691d7e5ccf607ee72366aa0b7b19474c71e4.tar.bz2
forums-34c1691d7e5ccf607ee72366aa0b7b19474c71e4.tar.xz
forums-34c1691d7e5ccf607ee72366aa0b7b19474c71e4.zip
[ticket/12433] Use a different message when nesting of quotes is not allowed
PHPBB3-12433
Diffstat (limited to 'phpBB/includes/message_parser.php')
-rw-r--r--phpBB/includes/message_parser.php12
1 files changed, 10 insertions, 2 deletions
diff --git a/phpBB/includes/message_parser.php b/phpBB/includes/message_parser.php
index 901bafbb2e..8bf50b0ca3 100644
--- a/phpBB/includes/message_parser.php
+++ b/phpBB/includes/message_parser.php
@@ -776,8 +776,16 @@ class bbcode_firstpass extends bbcode
// the buffer holds a valid opening tag
if ($config['max_quote_depth'] && sizeof($close_tags) >= $config['max_quote_depth'])
{
- // there are too many nested quotes
- $error_ary['quote_depth'] = $user->lang('QUOTE_DEPTH_EXCEEDED', (int) $config['max_quote_depth']);
+ if ($config['max_quote_depth'] == 1)
+ {
+ // Depth 1 - no nesting is allowed
+ $error_ary['quote_depth'] = $user->lang('QUOTE_NO_NESTING');
+ }
+ else
+ {
+ // There are too many nested quotes
+ $error_ary['quote_depth'] = $user->lang('QUOTE_DEPTH_EXCEEDED', (int) $config['max_quote_depth']);
+ }
$out .= $buffer . $tok;
$tok = '[]';